@@ -1214,6 +1214,7 @@ namespace PlansPlant
     QDateTime PlanFinish;
     if( UI.PlanGroup->isChecked() )
     {
+      Est = UI.Estimated->value();
       if( UI.HasStart->isChecked() )
 	PlanStart = UI.PlanStart->dateTime();
       if( UI.HasFinish->isChecked() )
@@ -1221,8 +1222,8 @@ namespace PlansPlant
 	PlanFinish = UI.PlanFinish->dateTime();
 	if( UI.HasStart->isChecked() )
 	{
-	  if( UI.Estimated > 0 )
-	    TimesOk = PlanFinish >= Task::add_time( PlanStart, UI.Estimated->value(), Task::TimeUnits( CurrUnits ) );
+	  if( Est > 0 )
+	    TimesOk = PlanFinish >= Task::add_time( PlanStart, Est, Task::TimeUnits( CurrUnits ) );
 	  else
 	    TimesOk = PlanFinish >= PlanStart;
 	  if( !TimesOk ) //! \todo Add auto-adjust options.
